import { Balances, ControlClaim, HypernetLink, PullPayment, PushPayment, PaymentId, GatewayUrl, BlockchainUnavailableError, ProxyError, InvalidParametersError, IHypernetCore, BigNumberString, ActiveStateChannel, ChainId, EthereumAccountAddress, ProviderId, InitializeStatus, CoreInitializationErrors, GovernanceSignerUnavailableError, ChainInformation, IHypernetPayments, IHypernetGovernance, IHypernetRegistries } from "@hypernetlabs/objects";
import { ParentProxy } from "@hypernetlabs/utils";
import { Result, ResultAsync } from "neverthrow";
import { Subject } from "rxjs";
export default class HypernetIFrameProxy extends ParentProxy implements IHypernetCore {
    protected element: HTMLElement | null;
    protected iframeUrl: string;
    protected iframeName: string;
    protected isInControl: boolean;
    protected _handshakePromise: Promise<void> | null;
    protected coreInitialized: boolean;
    protected waitInitializedPromise: Promise<void>;
    protected initializePromiseResolve: (() => void) | null;
    protected coreRegistriesInitialized: boolean;
    protected waitRegistriesInitializedPromise: Promise<void>;
    protected registriesInitializePromiseResolve: (() => void) | null;
    protected coreGovernanceInitialized: boolean;
    protected waitGovernanceInitializedPromise: Promise<void>;
    protected governanceInitializePromiseResolve: (() => void) | null;
    protected corePaymentsInitialized: boolean;
    protected waitPaymentsInitializedPromise: Promise<void>;
    protected paymentsInitializePromiseResolve: (() => void) | null;
    constructor(element: HTMLElement | null, iframeUrl: string, iframeName: string);
    finalizePullPayment(_paymentId: PaymentId, _finalAmount: BigNumberString): Promise<HypernetLink>;
    initialized(chainId?: ChainId): ResultAsync<boolean, ProxyError>;
    waitInitialized(chainId?: ChainId): ResultAsync<void, ProxyError>;
    inControl(): Result<boolean, never>;
    getEthereumAccounts(): ResultAsync<EthereumAccountAddress[], BlockchainUnavailableError | ProxyError>;
    initialize(chainId?: ChainId): ResultAsync<InitializeStatus, CoreInitializationErrors>;
    getInitializationStatus(): ResultAsync<InitializeStatus, ProxyError>;
    providePrivateCredentials(privateKey: string | null, mnemonic: string | null): ResultAsync<void, InvalidParametersError | ProxyError>;
    getBlockNumber(): ResultAsync<number, BlockchainUnavailableError | ProxyError>;
    provideProviderId(providerId: ProviderId): ResultAsync<void, InvalidParametersError | ProxyError>;
    retrieveChainInformationList(): ResultAsync<Map<ChainId, ChainInformation>, ProxyError>;
    retrieveGovernanceChainInformation(): ResultAsync<ChainInformation, ProxyError>;
    initializeForChainId(chainId: ChainId): ResultAsync<void, CoreInitializationErrors>;
    switchProviderNetwork(chainId: ChainId): ResultAsync<void, BlockchainUnavailableError | ProxyError>;
    getMainProviderChainId(): ResultAsync<ChainId, BlockchainUnavailableError | ProxyError>;
    payments: IHypernetPayments;
    governance: IHypernetGovernance;
    registries: IHypernetRegistries;
    private _displayCoreIFrame;
    private _closeCoreIFrame;
    /**
     * Observables for seeing what's going on
     */
    onControlClaimed: Subject<ControlClaim>;
    onControlYielded: Subject<ControlClaim>;
    onPushPaymentSent: Subject<PushPayment>;
    onPullPaymentSent: Subject<PullPayment>;
    onPushPaymentUpdated: Subject<PushPayment>;
    onPullPaymentUpdated: Subject<PullPayment>;
    onPushPaymentReceived: Subject<PushPayment>;
    onPullPaymentReceived: Subject<PullPayment>;
    onPushPaymentDelayed: Subject<PushPayment>;
    onPullPaymentDelayed: Subject<PullPayment>;
    onPushPaymentCanceled: Subject<PushPayment>;
    onPullPaymentCanceled: Subject<PullPayment>;
    onBalancesChanged: Subject<Balances>;
    onCeramicAuthenticationStarted: Subject<void>;
    onCeramicAuthenticationSucceeded: Subject<void>;
    onCeramicFailed: Subject<Error>;
    onGatewayAuthorized: Subject<GatewayUrl>;
    onGatewayDeauthorizationStarted: Subject<GatewayUrl>;
    onAuthorizedGatewayUpdated: Subject<GatewayUrl>;
    onAuthorizedGatewayActivationFailed: Subject<GatewayUrl>;
    onGatewayIFrameDisplayRequested: Subject<GatewayUrl>;
    onGatewayIFrameCloseRequested: Subject<GatewayUrl>;
    onCoreIFrameDisplayRequested: Subject<void>;
    onCoreIFrameCloseRequested: Subject<void>;
    onInitializationRequired: Subject<void>;
    onPrivateCredentialsRequested: Subject<void>;
    onWalletConnectOptionsDisplayRequested: Subject<void>;
    onStateChannelCreated: Subject<ActiveStateChannel>;
    onChainConnected: Subject<ChainId>;
    onGovernanceChainConnected: Subject<ChainId>;
    onChainChanged: Subject<ChainId>;
    onAccountChanged: Subject<EthereumAccountAddress>;
    onGovernanceChainChanged: Subject<ChainId>;
    onGovernanceAccountChanged: Subject<EthereumAccountAddress>;
    onGovernanceSignerUnavailable: Subject<GovernanceSignerUnavailableError>;
}
//# sourceMappingURL=HypernetIFrameProxy.d.ts.map